@@ -10,8 +10,7 @@ PUMP_EVENTS = "PUMP_EVENTS"
 
 DEFAULT_FEATURES = [
     BASAL,
-    BOLUS,
-    IOB
+    BOLUS
 ]
 
 ALL_FEATURES = [
