@@ -1,19 +1,26 @@
-import sys
+import datetime
 import requests
 import hashlib
 import time
 import urllib.parse
+import arrow
 
 from urllib.parse import urljoin
 
 from .api.common import ApiException
 from .parser.nightscout import ENTERED_BY
 
-# try:
-#     from .secret import NS_URL, NS_SECRET
-# except Exception:
-#     print('Unable to import Nightscout secrets from secret.py')
-#     sys.exit(1)
+def format_datetime(date):
+	return arrow.get(date).strftime('%Y-%m-%d %H:%M:%S')
+
+def time_range(field_name, start_time, end_time):
+	arg = ''
+	if start_time:
+		arg += '&find[%s][$gte]=%s' % (field_name, format_datetime(start_time))
+	if end_time:
+		arg += '&find[%s][$lte]=%s' % (field_name, format_datetime(end_time))
+	return arg
+
 
 class NightscoutApi:
 	def __init__(self, url, secret):
@@ -48,8 +55,9 @@ class NightscoutApi:
 		if r.status_code != 200:
 			raise ApiException(r.status_code, "Nightscout put response: %s" % r.text)
 
-	def last_uploaded_entry(self, eventType):
-		latest = requests.get(urljoin(self.url, 'api/v1/treatments?count=1&find[enteredBy]=' + urllib.parse.quote(ENTERED_BY) + '&find[eventType]=' + urllib.parse.quote(eventType) + '&ts=' + str(time.time())), headers={
+	def last_uploaded_entry(self, eventType, time_start=None, time_end=None):
+		dateFilter = time_range('created_at', time_start, time_end)
+		latest = requests.get(urljoin(self.url, 'api/v1/treatments?count=1&find[enteredBy]=' + urllib.parse.quote(ENTERED_BY) + '&find[eventType]=' + urllib.parse.quote(eventType) + dateFilter + '&ts=' + str(time.time())), headers={
 			'api-secret': hashlib.sha1(self.secret.encode()).hexdigest()
 		})
 		if latest.status_code != 200:
@@ -60,8 +68,9 @@ class NightscoutApi:
 			return j[0]
 		return None
 	
-	def last_uploaded_bg_entry(self):
-		latest = requests.get(urljoin(self.url, 'api/v1/entries.json?count=1&find[device]=' + urllib.parse.quote(ENTERED_BY) + '&ts=' + str(time.time())), headers={
+	def last_uploaded_bg_entry(self, time_start=None, time_end=None):
+		dateFilter = time_range('dateString', time_start, time_end)
+		latest = requests.get(urljoin(self.url, 'api/v1/entries.json?count=1&find[device]=' + urllib.parse.quote(ENTERED_BY) + dateFilter + '&ts=' + str(time.time())), headers={
 			'api-secret': hashlib.sha1(self.secret.encode()).hexdigest()
 		})
 		if latest.status_code != 200:
@@ -72,8 +81,9 @@ class NightscoutApi:
 			return j[0]
 		return None
 
-	def last_uploaded_activity(self, activityType):
-		latest = requests.get(urljoin(self.url, 'api/v1/activity?find[enteredBy]=' + urllib.parse.quote(ENTERED_BY) + '&find[activityType]=' + urllib.parse.quote(activityType) + '&ts=' + str(time.time())), headers={
+	def last_uploaded_activity(self, activityType, time_start=None, time_end=None):
+		dateFilter = time_range('created_at', time_start, time_end)
+		latest = requests.get(urljoin(self.url, 'api/v1/activity?find[enteredBy]=' + urllib.parse.quote(ENTERED_BY) + '&find[activityType]=' + urllib.parse.quote(activityType) + dateFilter + '&ts=' + str(time.time())), headers={
 			'api-secret': hashlib.sha1(self.secret.encode()).hexdigest()
 		})
 		if latest.status_code != 200:
